---
name: 🐞 Bug Report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
---

### Description
A clear and concise description of what the bug is.

### To Reproduce
Steps to reproduce the behavior:
1. Go to '...'
2. Run '...'
3. See error

### Expected behavior
A clear and concise description of what you expected to happen.

### Environment
 - OS: [e.g. Windows, macOS]
 - Python Version: [e.g. 3.10]
 - Library Version: [e.g. pandas 1.5.3]